package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.MallSchoolAppraiseClass;

/**
 * 评估分类Service接口
 *
 * @author lsm
 * @date 2023-10-19
 */
public interface IMallSchoolAppraiseClassService
{
    /**
     * 查询评估分类
     *
     * @param appraiseClassId 评估分类主键
     * @return 评估分类
     */
    public MallSchoolAppraiseClass selectMallSchoolAppraiseClassByAppraiseClassId(Long appraiseClassId);

    /**
     * 查询评估分类列表
     *
     * @param mallSchoolAppraiseClass 评估分类
     * @return 评估分类集合
     */
    public List<MallSchoolAppraiseClass> selectMallSchoolAppraiseClassList(MallSchoolAppraiseClass mallSchoolAppraiseClass);

    /**
     * 新增评估分类
     *
     * @param mallSchoolAppraiseClass 评估分类
     * @return 结果
     */
    public int insertMallSchoolAppraiseClass(MallSchoolAppraiseClass mallSchoolAppraiseClass);

    /**
     * 修改评估分类
     *
     * @param mallSchoolAppraiseClass 评估分类
     * @return 结果
     */
    public int updateMallSchoolAppraiseClass(MallSchoolAppraiseClass mallSchoolAppraiseClass);

    /**
     * 批量删除评估分类
     *
     * @param appraiseClassIds 需要删除的评估分类主键集合
     * @return 结果
     */
    public int deleteMallSchoolAppraiseClassByAppraiseClassIds(Long[] appraiseClassIds);

    /**
     * 删除评估分类信息
     *
     * @param appraiseClassId 评估分类主键
     * @return 结果
     */
    public int deleteMallSchoolAppraiseClassByAppraiseClassId(Long appraiseClassId);

    /**
     * 评估分类
     * @return 结果
     */
    public List<MallSchoolAppraiseClass> selectAppraiseClassList();
}

